use std::borrow::Cow;

pub(crate) type Result<T> = core::result::Result<T, Error>;

/// Custom error type for the Bandcamp client
#[derive(thiserror::Error, Debug)]
pub enum Error {
    /// Error from the HTTP client
    #[error("http error: {0}")]
    Http(#[from] reqwest::Error),
    /// Website parsing error
    #[error("website parsing error: {0}")]
    WebsiteParsing(Cow<'static, str>),
    /// Item not found on Bandcamp
    #[error("{0}")]
    NotFound(Cow<'static, str>),
    /// Other error from Bandcamp
    #[error("{0}")]
    Bandcamp(Cow<'static, str>),
    /// Invalid bandcamp url
    #[error("invalid bandcamp url")]
    InvalidUrl,
    /// Invalid album UID
    #[error("invalid album uid")]
    InvalidUid,
}
