#![doc = include_str!("../README.md")]
#![warn(clippy::todo, missing_docs)]

mod error;
mod image;
mod img_formats;
mod requests;
mod serializer;
mod util;

pub mod models;
pub use error::Error;
pub use image::ImageUrl;
pub use img_formats::ImageFormat;

use reqwest::{Client, ClientBuilder};

const API_URL: &str = "https://bandcamp.com/api/";
const IMG_URL: &str = "https://f4.bcbits.com/img/";
const USER_AGENT: &str = "Dalvik/2.1.0 (Linux; U; Android 13; Pixel 6 Build/T3B2.230316.003)";

/// Bandcamp client
///
/// You do **not** have to wrap the client in an [`Rc`] or [`Arc`] to **reuse** it,
/// because it already uses an [`Arc`] internally.
#[derive(Clone)]
pub struct Bandcamp {
    client: Client,
}

impl Default for Bandcamp {
    fn default() -> Self {
        Self::new()
    }
}

impl Bandcamp {
    /// Create a new Bandcamp client
    pub fn new() -> Self {
        Self::with_ua(USER_AGENT)
    }

    /// Create a new Bandcamp client with the given user agent
    pub fn with_ua<S: AsRef<str>>(ua: S) -> Self {
        let client = ClientBuilder::new()
            .user_agent(ua.as_ref())
            .gzip(true)
            .build()
            .expect("http client could not be constructed");
        Self { client }
    }
}
